clear;

% Indifference curve between lag-augmented LP, lag-augmented AR, and non-augmented LP
% MPM 2019-08-19, 2020-03-13


%% Settings

hmax = 40; % Max horizon


%% LA-LP vs. LA-AR

% Indifference function
f = @(rho2,h) (1-rho2.^(-h))./(1-1./rho2)-h.^2; % Indifference function

% Compute indifference point
hs = 2:hmax;
rho2_indiffs = zeros(1,length(hs));
opts = optimset('Display', 'final');
for i=1:length(hs)
    disp(i);
    rho2_indiffs(i) = fzero(@(rho2) f(rho2,hs(i)), [0.001 0.999], opts);
end

% Plot indifference curve
figure;
plot(hs,sqrt(rho2_indiffs),'-ks');
xlabel('$h$', 'Interpreter', 'Latex');
ylabel('$|\rho|$', 'Interpreter', 'Latex');
grid on;


%% LA-LP vs. non-augmented LP

% Indifference function
f2 = @(rho2,h) (1-rho2.^h)./(1-rho2)-1-(2*h-1).*(rho2.^h);

% Compute indifference points
rho2_indiffs2 = zeros(1,length(hs));
for i=1:length(hs)
    disp(i);
    rho2_indiffs2(i) = fzero(@(rho2) f2(rho2,hs(i)), [0.001 0.999], opts);
end

% Plot indifference curve
figure;
plot(hs,sqrt(rho2_indiffs2),'-ks');
xlabel('$h$', 'Interpreter', 'Latex');
ylabel('$|\rho|$', 'Interpreter', 'Latex');
grid on;


%% Plot comparison of all three

figure;
hold on;
fill([hs, fliplr(hs)], [sqrt(rho2_indiffs), fliplr(ones(size(rho2_indiffs)))], [0.8 0.8 0.8]);
fill2 = fill([hs, fliplr(hs)], [sqrt(rho2_indiffs2), fliplr(zeros(size(rho2_indiffs2)))], 'w', 'FaceAlpha',0);
hatchfill2(fill2, 'single');
plot(hs, sqrt(rho2_indiffs), '-k', 'LineWidth', 2);
plot(hs, sqrt(rho2_indiffs2), '-k', 'LineWidth', 2);
hold off;
xlim([min(hs) max(hs)]);
xlabel('horizon $h$', 'Interpreter', 'Latex', 'FontSize', 14);
ylabel('persistence $|\rho|$', 'Interpreter', 'Latex', 'FontSize', 14);
ylim([0 1]);
set(gca,'FontSize',12);
annotation('textbox',[0.55 0.3 0.01 0.01],'Interpreter','Latex','String','$\mathrm{LP}_{\mathrm{LA}}$ beats $\mathrm{LP}_{\mathrm{NA}}$','BackgroundColor','w','FontSize',14,'FitBoxToText','on','Margin',3,'HorizontalAlignment','center','VerticalAlignment','middle');
annotation('textarrow',[0.45 0.4],[0.8 0.86],'Interpreter','Latex','String','$\mathrm{LP}_{\mathrm{LA}}$ beats $\mathrm{AR}_{\mathrm{LA}}$ \& $\mathrm{LP}_{\mathrm{NA}}$','TextBackgroundColor','w','TextEdgeColor','k','FontSize',14);
annotation('textarrow',[0.27 0.18],[0.68 0.88],'Interpreter','Latex','String','$\mathrm{LP}_{\mathrm{LA}}$ beats $\mathrm{AR}_{\mathrm{LA}}$','TextBackgroundColor','w','TextEdgeColor','k','FontSize',14);
